@@ -1,5 +1,5 @@
 // Test with command:
-// ./cppcheck --enable=information --addon=misra --inline-suppr addons/test/misra/misra-ctu-*-test.c
+// ./cppcheck --enable=information --enable=style --addon=misra --inline-suppr addons/test/misra/misra-ctu-*-test.c
 
 #include "misra-ctu-test.h"
 
@@ -43,7 +43,11 @@ extern int misra_8_5;
 // cppcheck-suppress misra-c2012-8.4
 // cppcheck-suppress misra-c2012-8.6
 int32_t misra_8_6 = 2;
-
+// cppcheck-suppress misra-c2012-8.4
+int32_t misra_8_6_1;
+// cppcheck-suppress misra-c2012-8.7
+// cppcheck-suppress misra-c2012-8.4
+int32_t misra_8_6_1 = 2;
 // cppcheck-suppress misra-c2012-8.4
 // cppcheck-suppress misra-c2012-8.7
 void misra_8_7(void) {}
