@@ -19,15 +19,18 @@
 #ifndef THREADEXECUTOR_H
 #define THREADEXECUTOR_H
 
+#include "cppcheck.h"
 #include "executor.h"
 
 #include <cstddef>
-#include <map>
+#include <list>
 #include <string>
+#include <utility>
 
 class Settings;
 class ErrorLogger;
 class Suppressions;
+struct FileSettings;
 
 /// @addtogroup CLI
 /// @{
@@ -37,14 +40,16 @@ class Suppressions;
  * all files using threads.
  */
 class ThreadExecutor : public Executor {
+    friend class SyncLogForwarder;
+
 public:
-    ThreadExecutor(const std::map<std::string, std::size_t> &files, const Settings &settings, Suppressions &suppressions, ErrorLogger &errorLogger);
+    ThreadExecutor(const std::list<std::pair<std::string, std::size_t>> &files, const std::list<FileSettings>& fileSettings, const Settings &settings, Suppressions &suppressions, ErrorLogger &errorLogger, CppCheck::ExecuteCmdFn executeCommand);
     ThreadExecutor(const ThreadExecutor &) = delete;
     void operator=(const ThreadExecutor &) = delete;
 
     unsigned int check() override;
 
-    friend class SyncLogForwarder;
+    CppCheck::ExecuteCmdFn mExecuteCommand;
 };
 
 /// @}
