@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2022 Cppcheck team.
+ * Copyright (C) 2007-2023 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
 #define ABOUT_DIALOG_H
 
 #include <QDialog>
+#include <QObject>
 #include <QString>
 
-class QObject;
 class QWidget;
 namespace Ui {
     class About;
