@@ -41,22 +41,22 @@ void CheckStatistics::addItem(const QString &tool, ShowTypes::ShowType type)
     const QString lower = tool.toLower();
     switch (type) {
     case ShowTypes::ShowStyle:
-        ::addItem(mStyle, tool);
+        ::addItem(mStyle, lower);
         break;
     case ShowTypes::ShowWarnings:
-        ::addItem(mWarning, tool);
+        ::addItem(mWarning, lower);
         break;
     case ShowTypes::ShowPerformance:
-        ::addItem(mPerformance, tool);
+        ::addItem(mPerformance, lower);
         break;
     case ShowTypes::ShowPortability:
-        ::addItem(mPortability, tool);
+        ::addItem(mPortability, lower);
         break;
     case ShowTypes::ShowErrors:
-        ::addItem(mError, tool);
+        ::addItem(mError, lower);
         break;
     case ShowTypes::ShowInformation:
-        ::addItem(mInformation, tool);
+        ::addItem(mInformation, lower);
         break;
     case ShowTypes::ShowNone:
     default:
@@ -65,6 +65,11 @@ void CheckStatistics::addItem(const QString &tool, ShowTypes::ShowType type)
     }
 }
 
+void CheckStatistics::addChecker(const QString &checker)
+{
+    mActiveCheckers.insert(checker.toStdString());
+}
+
 void CheckStatistics::clear()
 {
     mStyle.clear();
@@ -73,6 +78,8 @@ void CheckStatistics::clear()
     mPortability.clear();
     mInformation.clear();
     mError.clear();
+    mActiveCheckers.clear();
+    mCheckersReport.clear();
 }
 
 unsigned CheckStatistics::getCount(const QString &tool, ShowTypes::ShowType type) const
