@@ -36,8 +36,6 @@
 #define SETTINGS_WINDOW_MAXIMIZED       "Window maximized"
 #define SETTINGS_WINDOW_WIDTH           "Window width"
 #define SETTINGS_WINDOW_HEIGHT          "Window height"
-#define SETTINGS_LOG_VIEW_WIDTH         "Log/View width"
-#define SETTINGS_LOG_VIEW_HEIGHT        "Log/View height"
 #define SETTINGS_MAINWND_SPLITTER_STATE "Mainwindow/Vertical splitter state"
 #define SETTINGS_CHECK_DIALOG_WIDTH     "Check dialog width"
 #define SETTINGS_CHECK_DIALOG_HEIGHT    "Check dialog height"
@@ -101,7 +99,6 @@
 #define SETTINGS_LAST_PROJECT_PATH      "Last project path"
 #define SETTINGS_LAST_RESULT_PATH       "Last result path"
 #define SETTINGS_LAST_SOURCE_PATH       "Last source path"
-#define SETTINGS_LAST_INCLUDE_PATH      "Last include path"
 #define SETTINGS_LAST_APP_PATH          "Last application path"
 
 #define SETTINGS_LAST_ANALYZE_FILES_FILTER  "Last analyze files filter"
