@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2021 Cppcheck team.
+ * Copyright (C) 2007-2023 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,9 @@
 #ifndef FILELIST_H
 #define FILELIST_H
 
+#include <QFileInfo>
 #include <QFileInfoList>
+#include <QString>
 #include <QStringList>
 
 /**
