@@ -34,7 +34,7 @@ namespace Ui {
 
 class HelpBrowser : public QTextBrowser {
 public:
-    explicit HelpBrowser(QWidget* parent = nullptr) : QTextBrowser(parent), mHelpEngine(nullptr) {}
+    explicit HelpBrowser(QWidget* parent = nullptr) : QTextBrowser(parent) {}
     HelpBrowser(const HelpBrowser&) = delete;
     HelpBrowser(HelpBrowser&&) = delete;
     HelpBrowser& operator=(const HelpBrowser&) = delete;
@@ -42,7 +42,7 @@ public:
     void setHelpEngine(QHelpEngine *helpEngine);
     QVariant loadResource(int type, const QUrl& name) override;
 private:
-    QHelpEngine* mHelpEngine;
+    QHelpEngine* mHelpEngine{};
 };
 
 class HelpDialog : public QDialog {
