@@ -25,15 +25,21 @@
 #include "common.h"
 #include "csvreport.h"
 #include "erroritem.h"
+#include "errorlogger.h"
+#include "errortypes.h"
 #include "path.h"
 #include "printablereport.h"
 #include "resultstree.h"
+#include "settings.h"
 #include "txtreport.h"
 #include "xmlreport.h"
 #include "xmlreportv2.h"
 
 #include "ui_resultsview.h"
 
+#include <set>
+#include <string>
+
 #include <QAbstractItemModel>
 #include <QApplication>
 #include <QByteArray>
@@ -45,6 +51,7 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QIODevice>
+#include <QLabel>
 #include <QList>
 #include <QListWidget>
 #include <QListWidgetItem>
@@ -154,13 +161,16 @@ void ResultsView::progress(int value, const QString& description)
 
 void ResultsView::error(const ErrorItem &item)
 {
-    if (item.severity == Severity::none && (item.errorId == "logChecker" || item.errorId.endsWith("-logChecker"))) {
+    if (item.severity == Severity::internal && (item.errorId == "logChecker" || item.errorId.endsWith("-logChecker"))) {
         mStatistics->addChecker(item.message);
         return;
     }
 
     handleCriticalError(item);
 
+    if (item.severity == Severity::internal)
+        return;
+
     if (mUI->mTree->addErrorItem(item)) {
         emit gotResults();
         mStatistics->addItem(item.tool(), ShowTypes::SeverityToShowType(item.severity));
@@ -555,10 +565,14 @@ void ResultsView::handleCriticalError(const ErrorItem &item)
             if (!mCriticalErrors.isEmpty())
                 mCriticalErrors += ",";
             mCriticalErrors += item.errorId;
+            if (item.severity == Severity::internal)
+                mCriticalErrors += " (suppressed)";
         }
         QString msg = tr("There was a critical error with id '%1'").arg(item.errorId);
         if (!item.file0.isEmpty())
             msg += ", " + tr("when checking %1").arg(item.file0);
+        else
+            msg += ", " + tr("when checking a file");
         msg += ". " + tr("Analysis was aborted.");
         mUI->mLabelCriticalErrors->setText(msg);
         mUI->mLabelCriticalErrors->setVisible(true);
