@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2022 Cppcheck team.
+ * Copyright (C) 2007-2023 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 
 #include "ui_scratchpad.h"
 
+#include <QLineEdit>
+#include <QPushButton>
+
 ScratchPad::ScratchPad(MainWindow& mainWindow)
     : QDialog(&mainWindow)
     , mUI(new Ui::ScratchPad)
