@@ -185,7 +185,7 @@ protected:
      * @param box checkbox to save
      * @param name name for QSettings to store the value
      */
-    static void saveCheckboxValue(QSettings *settings, QCheckBox *box, const QString &name);
+    static void saveCheckboxValue(QSettings *settings, const QCheckBox *box, const QString &name);
 
     /**
      * @brief Convert bool to Qt::CheckState
@@ -240,7 +240,7 @@ protected:
 private:
     void manageStyleControls();
 
-    static const int mLangCodeRole = Qt::UserRole;
+    static constexpr int mLangCodeRole = Qt::UserRole;
 
     bool mPremium;
 };
