@@ -22,6 +22,7 @@
 #include "erroritem.h"
 #include "errorlogger.h"
 #include "errortypes.h"
+#include "importproject.h"
 
 #include <numeric>
 
@@ -35,7 +36,7 @@ void ThreadResult::reportOut(const std::string &outmsg, Color /*c*/)
 
 void ThreadResult::fileChecked(const QString &file)
 {
-    QMutexLocker locker(&mutex);
+    std::lock_guard<std::mutex> locker(mutex);
 
     mProgress += QFile(file).size();
     mFilesChecked++;
@@ -50,7 +51,7 @@ void ThreadResult::fileChecked(const QString &file)
 
 void ThreadResult::reportErr(const ErrorMessage &msg)
 {
-    QMutexLocker locker(&mutex);
+    std::lock_guard<std::mutex> locker(mutex);
     const ErrorItem item(msg);
     if (msg.severity != Severity::debug)
         emit error(item);
@@ -60,7 +61,7 @@ void ThreadResult::reportErr(const ErrorMessage &msg)
 
 QString ThreadResult::getNextFile()
 {
-    QMutexLocker locker(&mutex);
+    std::lock_guard<std::mutex> locker(mutex);
     if (mFiles.isEmpty()) {
         return QString();
     }
@@ -68,20 +69,20 @@ QString ThreadResult::getNextFile()
     return mFiles.takeFirst();
 }
 
-ImportProject::FileSettings ThreadResult::getNextFileSettings()
+FileSettings ThreadResult::getNextFileSettings()
 {
-    QMutexLocker locker(&mutex);
+    std::lock_guard<std::mutex> locker(mutex);
     if (mFileSettings.empty()) {
-        return ImportProject::FileSettings();
+        return FileSettings();
     }
-    const ImportProject::FileSettings fs = mFileSettings.front();
+    const FileSettings fs = mFileSettings.front();
     mFileSettings.pop_front();
     return fs;
 }
 
 void ThreadResult::setFiles(const QStringList &files)
 {
-    QMutexLocker locker(&mutex);
+    std::lock_guard<std::mutex> locker(mutex);
     mFiles = files;
     mProgress = 0;
     mFilesChecked = 0;
@@ -97,7 +98,7 @@ void ThreadResult::setFiles(const QStringList &files)
 
 void ThreadResult::setProject(const ImportProject &prj)
 {
-    QMutexLocker locker(&mutex);
+    std::lock_guard<std::mutex> locker(mutex);
     mFiles.clear();
     mFileSettings = prj.fileSettings;
     mProgress = 0;
@@ -106,14 +107,14 @@ void ThreadResult::setProject(const ImportProject &prj)
 
     // Determine the total size of all of the files to check, so that we can
     // show an accurate progress estimate
-    mMaxProgress = std::accumulate(prj.fileSettings.begin(), prj.fileSettings.end(), quint64{ 0 }, [](quint64 v, const ImportProject::FileSettings& fs) {
+    mMaxProgress = std::accumulate(prj.fileSettings.begin(), prj.fileSettings.end(), quint64{ 0 }, [](quint64 v, const FileSettings& fs) {
         return v + QFile(QString::fromStdString(fs.filename)).size();
     });
 }
 
 void ThreadResult::clearFiles()
 {
-    QMutexLocker locker(&mutex);
+    std::lock_guard<std::mutex> locker(mutex);
     mFiles.clear();
     mFileSettings.clear();
     mFilesChecked = 0;
@@ -122,6 +123,6 @@ void ThreadResult::clearFiles()
 
 int ThreadResult::getFileCount() const
 {
-    QMutexLocker locker(&mutex);
+    std::lock_guard<std::mutex> locker(mutex);
     return mFiles.size() + mFileSettings.size();
 }
