@@ -22,18 +22,19 @@
 
 #include "color.h"
 #include "errorlogger.h"
-#include "importproject.h"
+#include "filesettings.h"
 
 #include <list>
+#include <mutex>
 #include <string>
 
-#include <QMutex>
 #include <QObject>
 #include <QString>
 #include <QStringList>
 #include <QtGlobal>
 
 class ErrorItem;
+class ImportProject;
 
 /// @addtogroup GUI
 /// @{
@@ -53,7 +54,7 @@ public:
      */
     QString getNextFile();
 
-    ImportProject::FileSettings getNextFileSettings();
+    FileSettings getNextFileSettings();
 
     /**
      * @brief Set list of files to check
@@ -127,7 +128,7 @@ protected:
      * @brief Mutex
      *
      */
-    mutable QMutex mutex;
+    mutable std::mutex mutex;
 
     /**
      * @brief List of files to check
@@ -135,7 +136,7 @@ protected:
      */
     QStringList mFiles;
 
-    std::list<ImportProject::FileSettings> mFileSettings;
+    std::list<FileSettings> mFileSettings;
 
     /**
      * @brief Max progress
