@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 from setuptools import setup
 
@@ -7,9 +7,9 @@ with open('README.txt') as f:
 
 setup(
     name="cppcheck",
-    description='Python script to parse the XML (version 2) output of '
-    + 'cppcheck and generate an HTML report using Pygments for syntax '
-    + 'highlighting.',
+    description='Python script to parse the XML (version 2) output of ' +
+                'cppcheck and generate an HTML report using Pygments for syntax ' +
+                'highlighting.',
     long_description=readme,
     author='Henrik Nilsson',
     url='https://github.com/danmar/cppcheck',
