@@ -23,6 +23,7 @@
 //---------------------------------------------------------------------------
 
 #include <functional>
+#include <list>
 #include <stack>
 #include <string>
 #include <type_traits>
@@ -31,6 +32,7 @@
 #include "config.h"
 #include "errortypes.h"
 #include "library.h"
+#include "mathlib.h"
 #include "smallvector.h"
 #include "symboldatabase.h"
 #include "token.h"
@@ -114,6 +116,21 @@ const Token* findExpression(const nonneg int exprid,
                             const std::function<bool(const Token*)>& pred);
 const Token* findExpression(const Token* start, const nonneg int exprid);
 
+template<class T, class OuputIterator, REQUIRES("T must be a Token class", std::is_convertible<T*, const Token*> )>
+void astFlattenCopy(T* tok, const char* op, OuputIterator out, nonneg int depth = 100)
+{
+    --depth;
+    if (!tok || depth < 0)
+        return;
+    if (tok->str() == op) {
+        astFlattenCopy(tok->astOperand1(), op, out, depth);
+        astFlattenCopy(tok->astOperand2(), op, out, depth);
+    } else {
+        *out = tok;
+        ++out;
+    }
+}
+
 std::vector<const Token*> astFlatten(const Token* tok, const char* op);
 std::vector<Token*> astFlatten(Token* tok, const char* op);
 
@@ -121,6 +138,7 @@ nonneg int astCount(const Token* tok, const char* op, int depth = 100);
 
 bool astHasToken(const Token* root, const Token * tok);
 
+bool astHasExpr(const Token* tok, nonneg int exprid);
 bool astHasVar(const Token * tok, nonneg int varid);
 
 bool astIsPrimitive(const Token* tok);
@@ -333,17 +351,25 @@ bool isVariablesChanged(const Token* start,
                         bool cpp);
 
 bool isThisChanged(const Token* tok, int indirect, const Settings* settings, bool cpp);
-bool isThisChanged(const Token* start, const Token* end, int indirect, const Settings* settings, bool cpp);
+const Token* findThisChanged(const Token* start, const Token* end, int indirect, const Settings* settings, bool cpp);
 
 const Token* findVariableChanged(const Token *start, const Token *end, int indirect, const nonneg int exprid, bool globalvar, const Settings *settings, bool cpp, int depth = 20);
 Token* findVariableChanged(Token *start, const Token *end, int indirect, const nonneg int exprid, bool globalvar, const Settings *settings, bool cpp, int depth = 20);
 
-CPPCHECKLIB bool isExpressionChanged(const Token* expr,
-                                     const Token* start,
-                                     const Token* end,
-                                     const Settings* settings,
-                                     bool cpp,
-                                     int depth = 20);
+CPPCHECKLIB const Token* findExpressionChanged(const Token* expr,
+                                               const Token* start,
+                                               const Token* end,
+                                               const Settings* settings,
+                                               bool cpp,
+                                               int depth = 20);
+
+const Token* findExpressionChangedSkipDeadCode(const Token* expr,
+                                               const Token* start,
+                                               const Token* end,
+                                               const Settings* settings,
+                                               bool cpp,
+                                               const std::function<std::vector<MathLib::bigint>(const Token* tok)>& evaluate,
+                                               int depth = 20);
 
 bool isExpressionChangedAt(const Token* expr,
                            const Token* tok,
@@ -383,7 +409,7 @@ const Token* getIteratorExpression(const Token* tok);
 /**
  * Are the arguments a pair of iterators/pointers?
  */
-bool isIteratorPair(std::vector<const Token*> args);
+bool isIteratorPair(const std::vector<const Token*>& args);
 
 CPPCHECKLIB const Token *findLambdaStartToken(const Token *last);
 
@@ -408,6 +434,8 @@ bool isCPPCast(const Token* tok);
 
 bool isConstVarExpression(const Token* tok, std::function<bool(const Token*)> skipPredicate = nullptr);
 
+bool isLeafDot(const Token* tok);
+
 enum class ExprUsage { None, NotUsed, PassedByReference, Used, Inconclusive };
 
 ExprUsage getExprUsage(const Token* tok, int indirect, const Settings* settings, bool cpp);
