@@ -16,12 +16,16 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#pragma once
+#ifndef checkersReportH
+#define checkersReportH
+
+#include "config.h"
 
-#include "settings.h"
 #include <set>
 #include <string>
 
+class Settings;
+
 class CPPCHECKLIB CheckersReport {
 public:
     CheckersReport(const Settings& settings, const std::set<std::string>& activeCheckers);
@@ -41,4 +45,4 @@ private:
     int mAllCheckersCount = 0;
 };
 
-
+#endif
