@@ -24,7 +24,6 @@
 
 #include "check.h"
 #include "config.h"
-#include "ctu.h"
 #include "tokenize.h"
 #include "vfvalue.h"
 
@@ -36,6 +35,10 @@ class Library;
 class Settings;
 class Token;
 
+namespace CTU {
+    class FileInfo;
+}
+
 namespace tinyxml2 {
     class XMLElement;
 }
@@ -47,32 +50,12 @@ namespace tinyxml2 {
 /** @brief check for null pointer dereferencing */
 
 class CPPCHECKLIB CheckNullPointer : public Check {
+    friend class TestNullPointer;
+
 public:
     /** @brief This constructor is used when registering the CheckNullPointer */
     CheckNullPointer() : Check(myName()) {}
 
-    /** @brief This constructor is used when running checks. */
-    CheckNullPointer(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger)
-        : Check(myName(), tokenizer, settings, errorLogger) {}
-
-    /** @brief Run checks against the normal token list */
-    void runChecks(const Tokenizer &tokenizer, ErrorLogger *errorLogger) override {
-        CheckNullPointer checkNullPointer(&tokenizer, tokenizer.getSettings(), errorLogger);
-        checkNullPointer.nullPointer();
-        checkNullPointer.arithmetic();
-        checkNullPointer.nullConstantDereference();
-    }
-
-    /**
-     * @brief parse a function call and extract information about variable usage
-     * @param tok first token
-     * @param var variables that the function read / write.
-     * @param library --library files data
-     */
-    static void parseFunctionCall(const Token &tok,
-                                  std::list<const Token *> &var,
-                                  const Library *library);
-
     /**
      * Is there a pointer dereference? Everything that should result in
      * a nullpointer dereference error message will result in a true
@@ -86,6 +69,29 @@ public:
 
     static bool isPointerDeRef(const Token *tok, bool &unknown, const Settings *settings);
 
+private:
+    /**
+     * @brief parse a function call and extract information about variable usage
+     * @param tok first token
+     * @param var variables that the function read / write.
+     * @param library --library files data
+     */
+    static void parseFunctionCall(const Token &tok,
+                                  std::list<const Token *> &var,
+                                  const Library *library);
+
+    /** @brief This constructor is used when running checks. */
+    CheckNullPointer(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger)
+        : Check(myName(), tokenizer, settings, errorLogger) {}
+
+    /** @brief Run checks against the normal token list */
+    void runChecks(const Tokenizer &tokenizer, ErrorLogger *errorLogger) override {
+        CheckNullPointer checkNullPointer(&tokenizer, tokenizer.getSettings(), errorLogger);
+        checkNullPointer.nullPointer();
+        checkNullPointer.arithmetic();
+        checkNullPointer.nullConstantDereference();
+    }
+
     /** @brief possible null pointer dereference */
     void nullPointer();
 
@@ -99,16 +105,6 @@ public:
     }
     void nullPointerError(const Token *tok, const std::string &varname, const ValueFlow::Value* value, bool inconclusive);
 
-    /* data for multifile checking */
-    class MyFileInfo : public Check::FileInfo {
-    public:
-        /** function arguments that are dereferenced without checking if they are null */
-        std::list<CTU::FileInfo::UnsafeUsage> unsafeUsage;
-
-        /** Convert MyFileInfo data into xml string */
-        std::string toString() const override;
-    };
-
     /** @brief Parse current TU and extract file info */
     Check::FileInfo *getFileInfo(const Tokenizer *tokenizer, const Settings *settings) const override;
 
@@ -117,7 +113,6 @@ public:
     /** @brief Analyse all file infos for all TU */
     bool analyseWholeProgram(const CTU::FileInfo *ctu, const std::list<Check::FileInfo*> &fileInfo, const Settings& settings, ErrorLogger &errorLogger) override;
 
-private:
     /** Get error messages. Used by --errorlist */
     void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings) const override {
         CheckNullPointer c(nullptr, settings, errorLogger);
