@@ -52,10 +52,7 @@ public:
     CheckUnusedFunctions(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger)
         : Check(myName(), tokenizer, settings, errorLogger) {}
 
-    static void clear() {
-        instance.mFunctions.clear();
-        instance.mFunctionCalls.clear();
-    }
+    static void clear();
 
     // Parse current tokens and determine..
     // * Check what functions are used
@@ -71,17 +68,14 @@ public:
     /** @brief Analyse all file infos for all TU */
     bool analyseWholeProgram(const CTU::FileInfo *ctu, const std::list<Check::FileInfo*> &fileInfo, const Settings& settings, ErrorLogger &errorLogger) override;
 
-    static CheckUnusedFunctions instance;
-
     std::string analyzerInfo() const;
 
     /** @brief Combine and analyze all analyzerInfos for all TUs */
     static void analyseWholeProgram(const Settings &settings, ErrorLogger * const errorLogger, const std::string &buildDir);
 
 private:
-
     void getErrorMessages(ErrorLogger *errorLogger, const Settings * /*settings*/) const override {
-        CheckUnusedFunctions::unusedFunctionError(errorLogger, emptyString, 0, "funcName");
+        CheckUnusedFunctions::unusedFunctionError(errorLogger, emptyString, 0, 0, "funcName");
     }
 
     void runChecks(const Tokenizer & /*tokenizer*/, ErrorLogger * /*errorLogger*/) override {}
@@ -90,7 +84,7 @@ private:
      * Dummy implementation, just to provide error for --errorlist
      */
     static void unusedFunctionError(ErrorLogger * const errorLogger,
-                                    const std::string &filename, unsigned int lineNumber,
+                                    const std::string &filename, unsigned int fileIndex, unsigned int lineNumber,
                                     const std::string &funcname);
 
     static std::string myName() {
@@ -104,6 +98,7 @@ private:
     struct CPPCHECKLIB FunctionUsage {
         std::string filename;
         unsigned int lineNumber{};
+        unsigned int fileIndex{};
         bool usedSameFile{};
         bool usedOtherFile{};
     };
