@@ -33,11 +33,15 @@
 class Token;
 
 /** @brief Simple container to be thrown when internal error is detected. */
-struct InternalError {
+struct CPPCHECKLIB InternalError {
     enum Type {AST, SYNTAX, UNKNOWN_MACRO, INTERNAL, LIMIT, INSTANTIATION};
+
     InternalError(const Token *tok, std::string errorMsg, Type type = INTERNAL);
+    InternalError(const Token *tok, std::string errorMsg, std::string details, Type type = INTERNAL);
+
     const Token *token;
     std::string errorMessage;
+    std::string details;
     Type type;
     std::string id;
 };
@@ -56,67 +60,67 @@ enum class Checks {
 };
 
 /** @brief enum class for severity. Used when reporting errors. */
-class CPPCHECKLIB Severity {
-public:
+enum class Severity {
     /**
-     * Message severities.
+     * No severity (default value).
      */
-    enum SeverityType {
-        /**
-         * No severity (default value).
-         */
-        none,
-        /**
-         * Programming error.
-         * This indicates severe error like memory leak etc.
-         * The error is certain.
-         */
-        error,
-        /**
-         * Warning.
-         * Used for dangerous coding style that can cause severe runtime errors.
-         * For example: forgetting to initialize a member variable in a constructor.
-         */
-        warning,
-        /**
-         * Style warning.
-         * Used for general code cleanup recommendations. Fixing these
-         * will not fix any bugs but will make the code easier to maintain.
-         * For example: redundant code, unreachable code, etc.
-         */
-        style,
-        /**
-         * Performance warning.
-         * Not an error as is but suboptimal code and fixing it probably leads
-         * to faster performance of the compiled code.
-         */
-        performance,
-        /**
-         * Portability warning.
-         * This warning indicates the code is not properly portable for
-         * different platforms and bitnesses (32/64 bit). If the code is meant
-         * to compile in different platforms and bitnesses these warnings
-         * should be fixed.
-         */
-        portability,
-        /**
-         * Checking information.
-         * Information message about the checking (process) itself. These
-         * messages inform about header files not found etc issues that are
-         * not errors in the code but something user needs to know.
-         */
-        information,
-        /**
-         * Debug message.
-         * Debug-mode message useful for the developers.
-         */
-        debug
-    };
-
-    static std::string toString(SeverityType severity);
-    static SeverityType fromString(const std::string &severity);
+    none,
+    /**
+     * Programming error.
+     * This indicates severe error like memory leak etc.
+     * The error is certain.
+     */
+    error,
+    /**
+     * Warning.
+     * Used for dangerous coding style that can cause severe runtime errors.
+     * For example: forgetting to initialize a member variable in a constructor.
+     */
+    warning,
+    /**
+     * Style warning.
+     * Used for general code cleanup recommendations. Fixing these
+     * will not fix any bugs but will make the code easier to maintain.
+     * For example: redundant code, unreachable code, etc.
+     */
+    style,
+    /**
+     * Performance warning.
+     * Not an error as is but suboptimal code and fixing it probably leads
+     * to faster performance of the compiled code.
+     */
+    performance,
+    /**
+     * Portability warning.
+     * This warning indicates the code is not properly portable for
+     * different platforms and bitnesses (32/64 bit). If the code is meant
+     * to compile in different platforms and bitnesses these warnings
+     * should be fixed.
+     */
+    portability,
+    /**
+     * Checking information.
+     * Information message about the checking (process) itself. These
+     * messages inform about header files not found etc issues that are
+     * not errors in the code but something user needs to know.
+     */
+    information,
+    /**
+     * Debug message.
+     * Debug-mode message useful for the developers.
+     */
+    debug,
+    /**
+     * Internal message.
+     * Message will not be shown to the user.
+     * Tracking what checkers is executed, tracking suppressed critical errors, etc.
+     */
+    internal
 };
 
+CPPCHECKLIB std::string severityToString(Severity severity);
+CPPCHECKLIB Severity severityFromString(const std::string &severity);
+
 struct CWE {
     explicit CWE(unsigned short cweId) : id(cweId) {}
     unsigned short id;
