@@ -19,14 +19,18 @@
 #ifndef jsonH
 #define jsonH
 
+#include "config.h"
+
 SUPPRESS_WARNING_PUSH("-Wfloat-equal")
 SUPPRESS_WARNING_CLANG_PUSH("-Wtautological-type-limit-compare")
-SUPPRESS_WARNING_GCC_PUSH("-Wparentheses")
+SUPPRESS_WARNING_CLANG_PUSH("-Wextra-semi-stmt")
+SUPPRESS_WARNING_CLANG_PUSH("-Wzero-as-null-pointer-constant")
 
 #define PICOJSON_USE_INT64
 #include <picojson.h>
 
-SUPPRESS_WARNING_GCC_POP
+SUPPRESS_WARNING_CLANG_POP
+SUPPRESS_WARNING_CLANG_POP
 SUPPRESS_WARNING_CLANG_POP
 SUPPRESS_WARNING_POP
 
