@@ -18,7 +18,7 @@
 
 #include "keywords.h"
 
-#include <cassert>
+#include "utils.h"
 
 // see https://en.cppreference.com/w/c/keyword
 
@@ -164,7 +164,7 @@ const std::unordered_set<std::string>& Keywords::getAll(Standards::cstd_t cStd)
         /*case Standards::cstd_t::C23:
             return c23_keywords_all;*/
     }
-    assert(false && "unreachable");
+    cppcheck::unreachable();
 }
 
 // cppcheck-suppress unusedFunction
@@ -184,7 +184,7 @@ const std::unordered_set<std::string>& Keywords::getAll(Standards::cppstd_t cppS
     case Standards::cppstd_t::CPP23:
         return cpp23_keywords_all;
     }
-    assert(false && "unreachable");
+    cppcheck::unreachable();
 }
 
 // cppcheck-suppress unusedFunction
@@ -201,7 +201,7 @@ const std::unordered_set<std::string>& Keywords::getOnly(Standards::cstd_t cStd)
         /*case Standards::cstd_t::C23:
             return c23_keywords_all;*/
     }
-    assert(false && "unreachable");
+    cppcheck::unreachable();
 }
 
 // cppcheck-suppress unusedFunction
@@ -222,6 +222,6 @@ const std::unordered_set<std::string>& Keywords::getOnly(Standards::cppstd_t cpp
     case Standards::cppstd_t::CPP23:
         return cpp23_keywords;
     }
-    assert(false && "unreachable");
+    cppcheck::unreachable();
 }
 
