@@ -23,10 +23,8 @@
 
 #include "config.h"
 #include "mathlib.h"
-#include "errortypes.h"
 #include "standards.h"
 
-#include <cstddef>
 #include <map>
 #include <memory>
 #include <set>
@@ -38,6 +36,7 @@
 
 class Token;
 class Settings;
+enum class Severity;
 
 namespace tinyxml2 {
     class XMLDocument;
@@ -54,8 +53,8 @@ class CPPCHECKLIB Library {
     // TODO: get rid of this
     friend class TestSymbolDatabase; // For testing only
     friend class TestSingleExecutorBase; // For testing only
-    friend class TestThreadExecutor; // For testing only
-    friend class TestProcessExecutor; // For testing only
+    friend class TestThreadExecutorBase; // For testing only
+    friend class TestProcessExecutorBase; // For testing only
 
 public:
     Library() = default;
@@ -75,9 +74,6 @@ public:
     Error load(const char exename[], const char path[]);
     Error load(const tinyxml2::XMLDocument &doc);
 
-    /** this is used for unit tests */
-    bool loadxmldata(const char xmldata[], std::size_t len);
-
     struct AllocFunc {
         int groupId;
         int arg;
@@ -107,50 +103,33 @@ public:
     /** get reallocation id for function */
     int getReallocId(const Token *tok, int arg) const;
 
+    // TODO: get rid of this
     /** get allocation info for function by name (deprecated, use other alloc) */
     const AllocFunc* getAllocFuncInfo(const char name[]) const {
         return getAllocDealloc(mAlloc, name);
     }
 
+    // TODO: get rid of this
     /** get deallocation info for function by name (deprecated, use other alloc) */
     const AllocFunc* getDeallocFuncInfo(const char name[]) const {
         return getAllocDealloc(mDealloc, name);
     }
 
+    // TODO: get rid of this
     /** get allocation id for function by name (deprecated, use other alloc) */
+    // cppcheck-suppress unusedFunction
     int allocId(const char name[]) const {
         const AllocFunc* af = getAllocDealloc(mAlloc, name);
         return af ? af->groupId : 0;
     }
 
+    // TODO: get rid of this
     /** get deallocation id for function by name (deprecated, use other alloc) */
     int deallocId(const char name[]) const {
         const AllocFunc* af = getAllocDealloc(mDealloc, name);
         return af ? af->groupId : 0;
     }
 
-    /** set allocation id for function */
-    void setalloc(const std::string &functionname, int id, int arg) {
-        mAlloc[functionname].groupId = id;
-        mAlloc[functionname].arg = arg;
-    }
-
-    void setdealloc(const std::string &functionname, int id, int arg) {
-        mDealloc[functionname].groupId = id;
-        mDealloc[functionname].arg = arg;
-    }
-
-    void setrealloc(const std::string &functionname, int id, int arg, int reallocArg = 1) {
-        mRealloc[functionname].groupId = id;
-        mRealloc[functionname].arg = arg;
-        mRealloc[functionname].reallocArg = reallocArg;
-    }
-
-    /** add noreturn function setting */
-    void setnoreturn(const std::string& funcname, bool noreturn) {
-        mNoReturn[funcname] = noreturn ? FalseTrueMaybe::True : FalseTrueMaybe::False;
-    }
-
     static bool isCompliantValidationExpression(const char* p);
 
     /** is allocation type memory? */
@@ -185,7 +164,7 @@ public:
     struct WarnInfo {
         std::string message;
         Standards standards;
-        Severity::SeverityType severity;
+        Severity severity;
     };
     std::map<std::string, WarnInfo> functionwarn;
 
@@ -218,6 +197,7 @@ public:
             PUSH,
             POP,
             FIND,
+            FIND_CONST,
             INSERT,
             ERASE,
             CHANGE_CONTENT,
@@ -459,8 +439,8 @@ public:
         char sign;
         enum class Type { NO, BOOL, CHAR, SHORT, INT, LONG, LONGLONG } stdtype;
     };
-    const struct PodType *podtype(const std::string &name) const {
-        const std::unordered_map<std::string, struct PodType>::const_iterator it = mPodTypes.find(name);
+    const PodType *podtype(const std::string &name) const {
+        const std::unordered_map<std::string, PodType>::const_iterator it = mPodTypes.find(name);
         return (it != mPodTypes.end()) ? &(it->second) : nullptr;
     }
 
@@ -488,7 +468,7 @@ public:
 
     struct Platform {
         const PlatformType *platform_type(const std::string &name) const {
-            const std::map<std::string, struct PlatformType>::const_iterator it = mPlatformTypes.find(name);
+            const std::map<std::string, PlatformType>::const_iterator it = mPlatformTypes.find(name);
             return (it != mPlatformTypes.end()) ? &(it->second) : nullptr;
         }
         std::map<std::string, PlatformType> mPlatformTypes;
@@ -599,7 +579,7 @@ private:
     std::map<std::string, ExportedFunctions> mExporters; // keywords that export variables/functions to libraries (meta-code/macros)
     std::map<std::string, std::set<std::string>> mImporters;  // keywords that import variables/functions
     std::map<std::string, int> mReflection; // invocation of reflection
-    std::unordered_map<std::string, struct PodType> mPodTypes; // pod types
+    std::unordered_map<std::string, PodType> mPodTypes; // pod types
     std::map<std::string, PlatformType> mPlatformTypes; // platform independent typedefs
     std::map<std::string, Platform> mPlatforms; // platform dependent typedefs
     std::map<std::pair<std::string,std::string>, TypeCheck> mTypeChecks;
