@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2022 Cppcheck team.
+ * Copyright (C) 2007-2023 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 
 #include "config.h"
 
-#include <atomic>
 #include <cstddef>
 #include <istream>
 #include <list>
@@ -36,6 +35,7 @@
 
 class ErrorLogger;
 class Settings;
+class Suppressions;
 
 /**
  * @brief A preprocessor directive
@@ -70,27 +70,27 @@ public:
  * configurations that exist in a source file.
  */
 class CPPCHECKLIB Preprocessor {
+    // TODO: get rid of this
+    friend class PreprocessorHelper;
+    friend class TestPreprocessor;
+
 public:
 
     /**
      * Include file types.
      */
     enum HeaderTypes {
-        NoHeader = 0,
-        UserHeader,
+        UserHeader = 1,
         SystemHeader
     };
 
     /** character that is inserted in expanded macros */
     static char macroChar;
 
-    explicit Preprocessor(Settings& settings, ErrorLogger *errorLogger = nullptr);
+    explicit Preprocessor(const Settings& settings, ErrorLogger *errorLogger = nullptr);
     virtual ~Preprocessor();
 
-    static std::atomic<bool> missingIncludeFlag;
-    static std::atomic<bool> missingSystemIncludeFlag;
-
-    void inlineSuppressions(const simplecpp::TokenList &tokens);
+    void inlineSuppressions(const simplecpp::TokenList &tokens, Suppressions &suppressions);
 
     void setDirectives(const simplecpp::TokenList &tokens);
     void setDirectives(const std::list<Directive> &directives) {
@@ -148,23 +148,6 @@ public:
 
     std::string getcode(const simplecpp::TokenList &tokens1, const std::string &cfg, std::vector<std::string> &files, const bool writeLocations);
 
-    /**
-     * Get preprocessed code for a given configuration
-     * @param filedata file data including preprocessing 'if', 'define', etc
-     * @param cfg configuration to read out
-     * @param filename name of source file
-     */
-    std::string getcode(const std::string &filedata, const std::string &cfg, const std::string &filename);
-
-    /**
-     * make sure empty configuration macros are not used in code. the given code must be a single configuration
-     * @param cfg configuration
-     * @param macroUsageList macro usage list
-     * @return true => configuration is valid
-     */
-    bool validateCfg(const std::string &cfg, const std::list<simplecpp::MacroUsage> &macroUsageList);
-    void validateCfgError(const std::string &file, const unsigned int line, const std::string &cfg, const std::string &macro);
-
     /**
      * Calculate HASH. Using toolinfo, tokens1, filedata.
      *
@@ -185,10 +168,6 @@ public:
 
     static void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings);
 
-    void setFile0(const std::string &f) {
-        mFile0 = f;
-    }
-
     /**
      * dump all directives present in source file
      */
@@ -196,11 +175,15 @@ public:
 
     void reportOutput(const simplecpp::OutputList &outputList, bool showerror);
 
+    static bool hasErrors(const simplecpp::Output &output);
+
 private:
     void missingInclude(const std::string &filename, unsigned int linenr, const std::string &header, HeaderTypes headerType);
     void error(const std::string &filename, unsigned int linenr, const std::string &msg);
 
-    Settings& mSettings;
+    static bool hasErrors(const simplecpp::OutputList &outputList);
+
+    const Settings& mSettings;
     ErrorLogger *mErrorLogger;
 
     /** list of all directives met while preprocessing file */
