@@ -19,7 +19,7 @@
 #include "suppressions.h"
 
 #include "errorlogger.h"
-#include "mathlib.h"
+#include "errortypes.h"
 #include "path.h"
 #include "utils.h"
 #include "token.h"
@@ -33,9 +33,12 @@
 #include <sstream> // IWYU pragma: keep
 #include <utility>
 
-#include <tinyxml2.h>
+#include "xml.h"
 
-Suppressions::ErrorMessage Suppressions::ErrorMessage::fromErrorMessage(const ::ErrorMessage &msg)
+static const char ID_UNUSEDFUNCTION[] = "unusedFunction";
+static const char ID_CHECKERSREPORT[] = "checkersReport";
+
+Suppressions::ErrorMessage Suppressions::ErrorMessage::fromErrorMessage(const ::ErrorMessage &msg, const std::set<std::string> &macroNames)
 {
     Suppressions::ErrorMessage ret;
     ret.hash = msg.hash;
@@ -48,6 +51,7 @@ Suppressions::ErrorMessage Suppressions::ErrorMessage::fromErrorMessage(const ::
     }
     ret.certainty = msg.certainty;
     ret.symbolNames = msg.symbolNames();
+    ret.macroNames = macroNames;
     return ret;
 }
 
@@ -57,9 +61,10 @@ static bool isAcceptedErrorIdChar(char c)
     case '_':
     case '-':
     case '.':
+    case '*':
         return true;
     default:
-        return std::isalnum(c);
+        return c > 0 && std::isalnum(c);
     }
 }
 
@@ -165,6 +170,8 @@ std::vector<Suppressions::Suppression> Suppressions::parseMultiSuppressComment(c
             return suppressions;
         }
 
+        const std::string symbolNameString = "symbolName=";
+
         while (iss) {
             std::string word;
             iss >> word;
@@ -172,8 +179,8 @@ std::vector<Suppressions::Suppression> Suppressions::parseMultiSuppressComment(c
                 break;
             if (word.find_first_not_of("+-*/%#;") == std::string::npos)
                 break;
-            if (word.compare(0, 11, "symbolName=") == 0) {
-                s.symbolName = word.substr(11);
+            if (startsWith(word, symbolNameString)) {
+                s.symbolName = word.substr(symbolNameString.size());
             } else {
                 if (errorMessage && errorMessage->empty())
                     *errorMessage = "Bad multi suppression '" + comment + "'. legal format is cppcheck-suppress[errorId, errorId symbolName=arr, ...]";
@@ -252,14 +259,12 @@ std::string Suppressions::addSuppression(Suppressions::Suppression suppression)
     if (suppression.errorId.empty() && suppression.hash == 0)
         return "Failed to add suppression. No id.";
 
-    if (suppression.errorId != "*") {
-        for (std::string::size_type pos = 0; pos < suppression.errorId.length(); ++pos) {
-            if (suppression.errorId[pos] < 0 || !isAcceptedErrorIdChar(suppression.errorId[pos])) {
-                return "Failed to add suppression. Invalid id \"" + suppression.errorId + "\"";
-            }
-            if (pos == 0 && std::isdigit(suppression.errorId[pos])) {
-                return "Failed to add suppression. Invalid id \"" + suppression.errorId + "\"";
-            }
+    for (std::string::size_type pos = 0; pos < suppression.errorId.length(); ++pos) {
+        if (!isAcceptedErrorIdChar(suppression.errorId[pos])) {
+            return "Failed to add suppression. Invalid id \"" + suppression.errorId + "\"";
+        }
+        if (pos == 0 && std::isdigit(suppression.errorId[pos])) {
+            return "Failed to add suppression. Invalid id \"" + suppression.errorId + "\"";
         }
     }
 
@@ -302,22 +307,34 @@ bool Suppressions::Suppression::parseComment(std::string comment, std::string *e
     if (comment.compare(comment.size() - 2, 2, "*/") == 0)
         comment.erase(comment.size() - 2, 2);
 
+    const std::set<std::string> cppchecksuppress{
+        "cppcheck-suppress",
+        "cppcheck-suppress-begin",
+        "cppcheck-suppress-end",
+        "cppcheck-suppress-file",
+        "cppcheck-suppress-macro"
+    };
+
     std::istringstream iss(comment.substr(2));
     std::string word;
     iss >> word;
-    if (word != "cppcheck-suppress")
+    if (!cppchecksuppress.count(word))
         return false;
+
     iss >> errorId;
     if (!iss)
         return false;
+
+    const std::string symbolNameString = "symbolName=";
+
     while (iss) {
         iss >> word;
         if (!iss)
             break;
         if (word.find_first_not_of("+-*/%#;") == std::string::npos)
             break;
-        if (word.compare(0,11,"symbolName=")==0)
-            symbolName = word.substr(11);
+        if (startsWith(word, symbolNameString))
+            symbolName = word.substr(symbolNameString.size());
         else if (errorMessage && errorMessage->empty())
             *errorMessage = "Bad suppression attribute '" + word + "'. You can write comments in the comment after a ; or //. Valid suppression attributes; symbolName=sym";
     }
@@ -330,10 +347,17 @@ bool Suppressions::Suppression::isSuppressed(const Suppressions::ErrorMessage &e
         return false;
     if (!errorId.empty() && !matchglob(errorId, errmsg.errorId))
         return false;
-    if (!fileName.empty() && !matchglob(fileName, errmsg.getFileName()))
-        return false;
-    if (lineNumber != NO_LINE && lineNumber != errmsg.lineNumber) {
-        if (!thisAndNextLine || lineNumber + 1 != errmsg.lineNumber)
+    if (type == Suppressions::Type::macro) {
+        if (errmsg.macroNames.count(macroName) == 0)
+            return false;
+    } else {
+        if (!fileName.empty() && !matchglob(fileName, errmsg.getFileName()))
+            return false;
+        if ((Suppressions::Type::unique == type) && (lineNumber != NO_LINE) && (lineNumber != errmsg.lineNumber)) {
+            if (!thisAndNextLine || lineNumber + 1 != errmsg.lineNumber)
+                return false;
+        }
+        if ((Suppressions::Type::block == type) && ((errmsg.lineNumber < lineBegin) || (errmsg.lineNumber > lineEnd)))
             return false;
     }
     if (!symbolName.empty()) {
@@ -377,7 +401,7 @@ std::string Suppressions::Suppression::getText() const
         ret += " symbolName=" + symbolName;
     if (hash > 0)
         ret += " hash=" + std::to_string(hash);
-    if (ret.compare(0,1," ")==0)
+    if (startsWith(ret," "))
         return ret.substr(1);
     return ret;
 }
@@ -385,22 +409,36 @@ std::string Suppressions::Suppression::getText() const
 bool Suppressions::isSuppressed(const Suppressions::ErrorMessage &errmsg, bool global)
 {
     const bool unmatchedSuppression(errmsg.errorId == "unmatchedSuppression");
+    bool returnValue = false;
     for (Suppression &s : mSuppressions) {
         if (!global && !s.isLocal())
             continue;
         if (unmatchedSuppression && s.errorId != errmsg.errorId)
             continue;
+        if (s.isMatch(errmsg))
+            returnValue = true;
+    }
+    return returnValue;
+}
+
+bool Suppressions::isSuppressedExplicitly(const Suppressions::ErrorMessage &errmsg, bool global)
+{
+    for (Suppression &s : mSuppressions) {
+        if (!global && !s.isLocal())
+            continue;
+        if (s.errorId != errmsg.errorId) // Error id must match exactly
+            continue;
         if (s.isMatch(errmsg))
             return true;
     }
     return false;
 }
 
-bool Suppressions::isSuppressed(const ::ErrorMessage &errmsg)
+bool Suppressions::isSuppressed(const ::ErrorMessage &errmsg, const std::set<std::string>& macroNames)
 {
     if (mSuppressions.empty())
         return false;
-    return isSuppressed(Suppressions::ErrorMessage::fromErrorMessage(errmsg));
+    return isSuppressed(Suppressions::ErrorMessage::fromErrorMessage(errmsg, macroNames));
 }
 
 void Suppressions::dump(std::ostream & out) const
@@ -429,9 +467,13 @@ std::list<Suppressions::Suppression> Suppressions::getUnmatchedLocalSuppressions
     for (const Suppression &s : mSuppressions) {
         if (s.matched || ((s.lineNumber != Suppression::NO_LINE) && !s.checked))
             continue;
+        if (s.type == Suppressions::Type::macro)
+            continue;
         if (s.hash > 0)
             continue;
-        if (!unusedFunctionChecking && s.errorId == "unusedFunction")
+        if (s.errorId == ID_CHECKERSREPORT)
+            continue;
+        if (!unusedFunctionChecking && s.errorId == ID_UNUSEDFUNCTION)
             continue;
         if (tmpFile.empty() || !s.isLocal() || s.fileName != tmpFile)
             continue;
@@ -448,7 +490,9 @@ std::list<Suppressions::Suppression> Suppressions::getUnmatchedGlobalSuppression
             continue;
         if (s.hash > 0)
             continue;
-        if (!unusedFunctionChecking && s.errorId == "unusedFunction")
+        if (!unusedFunctionChecking && s.errorId == ID_UNUSEDFUNCTION)
+            continue;
+        if (s.errorId == ID_CHECKERSREPORT)
             continue;
         if (s.isLocal())
             continue;
@@ -470,7 +514,15 @@ void Suppressions::markUnmatchedInlineSuppressionsAsChecked(const Tokenizer &tok
             currLineNr = tok->linenr();
             currFileIdx = tok->fileIndex();
             for (auto &suppression : mSuppressions) {
-                if (!suppression.checked && (suppression.lineNumber == currLineNr) && (suppression.fileName == tokenizer.list.file(tok))) {
+                if (suppression.type == Suppressions::Type::unique) {
+                    if (!suppression.checked && (suppression.lineNumber == currLineNr) && (suppression.fileName == tokenizer.list.file(tok))) {
+                        suppression.checked = true;
+                    }
+                } else if (suppression.type == Suppressions::Type::block) {
+                    if ((!suppression.checked && (suppression.lineBegin <= currLineNr) && (suppression.lineEnd >= currLineNr) && (suppression.fileName == tokenizer.list.file(tok)))) {
+                        suppression.checked = true;
+                    }
+                } else if (!suppression.checked && suppression.fileName == tokenizer.list.file(tok)) {
                     suppression.checked = true;
                 }
             }
