@@ -24,14 +24,12 @@
 #include "errortypes.h"
 #include "keywords.h"
 #include "library.h"
-#include "mathlib.h"
 #include "path.h"
 #include "platform.h"
 #include "settings.h"
 #include "standards.h"
 #include "token.h"
 
-#include <algorithm>
 #include <cctype>
 #include <exception>
 #include <functional>
@@ -45,7 +43,7 @@
 // How many compileExpression recursions are allowed?
 // For practical code this could be endless. But in some special torture test
 // there needs to be a limit.
-static const int AST_MAX_DEPTH = 150;
+static constexpr int AST_MAX_DEPTH = 150;
 
 
 TokenList::TokenList(const Settings* settings) :
@@ -307,6 +305,7 @@ void TokenList::insertTokens(Token *dest, const Token *src, nonneg int n)
         dest->varId(src->varId());
         dest->tokType(src->tokType());
         dest->flags(src->flags());
+        dest->setMacroName(src->getMacroName());
         src  = src->next();
         --n;
     }
@@ -364,7 +363,7 @@ void TokenList::createTokens(simplecpp::TokenList&& tokenList)
         mTokensFrontBack.back->fileIndex(tok->location.fileIndex);
         mTokensFrontBack.back->linenr(tok->location.line);
         mTokensFrontBack.back->column(tok->location.col);
-        mTokensFrontBack.back->isExpandedMacro(!tok->macro.empty());
+        mTokensFrontBack.back->setMacroName(tok->macro);
 
         tok = tok->next;
         if (tok)
@@ -397,17 +396,19 @@ std::size_t TokenList::calculateHash() const
 
 //---------------------------------------------------------------------------
 
-struct AST_state {
-    std::stack<Token*> op;
-    int depth{};
-    int inArrayAssignment{};
-    bool cpp;
-    int assign{};
-    bool inCase{}; // true from case to :
-    bool stopAtColon{}; // help to properly parse ternary operators
-    const Token* functionCallEndPar{};
-    explicit AST_state(bool cpp) : cpp(cpp) {}
-};
+namespace {
+    struct AST_state {
+        std::stack<Token*> op;
+        int depth{};
+        int inArrayAssignment{};
+        bool cpp;
+        int assign{};
+        bool inCase{}; // true from case to :
+        bool stopAtColon{}; // help to properly parse ternary operators
+        const Token* functionCallEndPar{};
+        explicit AST_state(bool cpp) : cpp(cpp) {}
+    };
+}
 
 static Token* skipDecl(Token* tok, std::vector<Token*>* inner = nullptr)
 {
@@ -1000,6 +1001,8 @@ static void compilePrecedence2(Token *&tok, AST_state& state)
                     compileUnaryOp(tok, state, nullptr);
             }
             tok = tok->link()->next();
+            if (Token::simpleMatch(tok, "::"))
+                compileBinOp(tok, state, compileTerm);
         } else if (iscast(tok, state.cpp) && Token::simpleMatch(tok->link(), ") {") && Token::simpleMatch(tok->link()->linkAt(1), "} [")) {
             Token *cast = tok;
             tok = tok->link()->next();
@@ -1444,9 +1447,20 @@ static Token * findAstTop(Token *tok1, const Token *tok2)
 static Token * createAstAtToken(Token *tok, bool cpp)
 {
     // skip function pointer declaration
+    if (Token::Match(tok, "%type% %type%") && !Token::Match(tok, "return|throw|new|delete")) {
+        Token* tok2 = tok->tokAt(2);
+        // skip type tokens and qualifiers etc
+        while (Token::Match(tok2, "%type%|*|&"))
+            tok2 = tok2->next();
+        if (Token::Match(tok2, "%var% [;,)]"))
+            return tok2;
+    }
     if (Token::Match(tok, "%type%") && !Token::Match(tok, "return|throw|if|while|new|delete")) {
+        bool isStandardTypeOrQualifier = false;
         Token* type = tok;
         while (Token::Match(type, "%type%|*|&|<")) {
+            if (type->isName() && (type->isStandardType() || Token::Match(type, "const|mutable|static|volatile")))
+                isStandardTypeOrQualifier = true;
             if (type->str() == "<") {
                 if (type->link())
                     type = type->link();
@@ -1455,6 +1469,8 @@ static Token * createAstAtToken(Token *tok, bool cpp)
             }
             type = type->next();
         }
+        if (isStandardTypeOrQualifier && Token::Match(type, "%var% [;,)]"))
+            return type;
         if (Token::Match(type, "( * *| %var%") &&
             Token::Match(type->link()->previous(), "%var%|] ) (") &&
             Token::Match(type->link()->linkAt(1), ") [;,)]"))
@@ -1689,16 +1705,18 @@ void TokenList::createAst() const
     }
 }
 
-struct OnException {
-    std::function<void()> f;
+namespace {
+    struct OnException {
+        std::function<void()> f;
 
-    ~OnException() {
+        ~OnException() {
 #ifndef _MSC_VER
-        if (std::uncaught_exception())
-            f();
+            if (std::uncaught_exception())
+                f();
 #endif
-    }
-};
+        }
+    };
+}
 
 void TokenList::validateAst() const
 {
@@ -1913,24 +1931,28 @@ void TokenList::simplifyPlatformTypes()
                 tok = tok->previous();
                 tok->deleteThis();
             }
+            tok->originalName(tok->str());
             Token *typeToken;
             if (platformtype->mConstPtr) {
                 tok->str("const");
-                tok->insertToken("*");
-                tok->insertToken(platformtype->mType);
+                tok->isSimplifiedTypedef(true);
+                tok->insertToken("*")->isSimplifiedTypedef(true);
+                tok->insertToken(platformtype->mType)->isSimplifiedTypedef(true);
                 typeToken = tok;
             } else if (platformtype->mPointer) {
                 tok->str(platformtype->mType);
+                tok->isSimplifiedTypedef(true);
                 typeToken = tok;
-                tok->insertToken("*");
+                tok->insertToken("*")->isSimplifiedTypedef(true);
             } else if (platformtype->mPtrPtr) {
                 tok->str(platformtype->mType);
+                tok->isSimplifiedTypedef(true);
                 typeToken = tok;
-                tok->insertToken("*");
-                tok->insertToken("*");
+                tok->insertToken("*")->isSimplifiedTypedef(true);
+                tok->insertToken("*")->isSimplifiedTypedef(true);
             } else {
-                tok->originalName(tok->str());
                 tok->str(platformtype->mType);
+                tok->isSimplifiedTypedef(true);
                 typeToken = tok;
             }
             if (platformtype->mSigned)
@@ -2038,14 +2060,13 @@ bool TokenList::isKeyword(const std::string &str) const
         if (cpp_types.find(str) != cpp_types.end())
             return false;
 
-        // TODO: properly apply configured standard
-        if (!mSettings || mSettings->standards.cpp >= Standards::CPP20) {
-            static const auto& cpp20_keywords = Keywords::getAll(Standards::cppstd_t::CPP20);
-            return cpp20_keywords.find(str) != cpp20_keywords.end();
+        if (mSettings) {
+            const auto &cpp_keywords = Keywords::getAll(mSettings->standards.cpp);
+            return cpp_keywords.find(str) != cpp_keywords.end();
         }
 
-        static const auto& cpp_keywords = Keywords::getAll(Standards::cppstd_t::CPP11);
-        return cpp_keywords.find(str) != cpp_keywords.end();
+        static const auto& latest_cpp_keywords = Keywords::getAll(Standards::cppstd_t::CPPLatest);
+        return latest_cpp_keywords.find(str) != latest_cpp_keywords.end();
     }
 
     // TODO: integrate into Keywords?
@@ -2054,7 +2075,11 @@ bool TokenList::isKeyword(const std::string &str) const
     if (c_types.find(str) != c_types.end())
         return false;
 
-    // TODO: use configured standard
-    static const auto& c_keywords = Keywords::getAll(Standards::cstd_t::C99);
-    return c_keywords.find(str) != c_keywords.end();
+    if (mSettings) {
+        const auto &c_keywords = Keywords::getAll(mSettings->standards.c);
+        return c_keywords.find(str) != c_keywords.end();
+    }
+
+    static const auto& latest_c_keywords = Keywords::getAll(Standards::cstd_t::CLatest);
+    return latest_c_keywords.find(str) != latest_c_keywords.end();
 }
