@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2021 Cppcheck team.
+ * Copyright (C) 2007-2023 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,12 @@
 
 #include "config.h"
 
+#include <cstddef>
+#include <iterator>
+#include <type_traits>
+
+class Token;
+
 template<typename T, REQUIRES("T must be a Token class", std::is_convertible<T*, const Token*> )>
 class TokenRangeBase {
     T* mFront;
