@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2022 Cppcheck team.
+ * Copyright (C) 2007-2023 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,11 +23,11 @@ enum class Color;
 
 class DummyErrorLogger : public ErrorLogger {
 public:
-    void reportOut(const std::string&, Color) override {}
-    void reportErr(const ErrorMessage&) override {}
-    void reportProgress(const std::string&,
-                        const char[],
-                        const std::size_t) override {}
+    void reportOut(const std::string& /*outmsg*/, Color /*c*/) override {}
+    void reportErr(const ErrorMessage& /*msg*/) override {}
+    void reportProgress(const std::string& /*filename*/,
+                        const char /*stage*/[],
+                        const std::size_t /*value*/) override {} // FN
 };
 
 extern "C" int LLVMFuzzerTestOneInput(const uint8_t *data, size_t dataSize);
